Changelog — Misaka 2.0.0 documentation

# Changelog

Date format is year-month-day.

## 2.0.0 (2015-07-??)

- Rewrite. CFFI and Hoedown instead of Cython and Sundown.
- Remove pre- and postprocessor support.
- Smartypants is a normal function instead of a postprocessor.
- Documentation now uses Sphinx.

## 1.0.3 (not released)

- `scripts/misaka`: Read stdin when no file is specified. (#22)
- SmartyPants is now a preprocessor. This fixes #19.
- Updated Sundown files; See commits from Mar 29, 2012 to Oct 19, 2012.

## 1.0.2 (2012-04-09)

- Added `clean`, `compile_cython` and `update_vendor` commands to `setup.py`. See `setup.py --help-commands` for more information.
- Removed the `--cython` install option.
- Sundown is now a Git submodule.
- Exceptions that are raised in render methods are now shown on STDOUT. The script execution will not stop. Only the render method will stop and return nothing.
- Removed trailing forward slashes from `MANIFEST.in`. These cause trouble on Windows. (#12/#13)
- Input text now be a byte or unicode string. Callback method arguments are always unicode. The returned text in a callback method can be a byte or unicode string.
- In Python 3 render callbacks couldn’t be seen, because the variable that was used to lookup the methods was a byte string. And Python 3 doesn’t see byte string and normalstrings as equal.
- Added unit tests.
- Updated Sundown files; See commits from Feb 05, 2012 to Mar 29, 2012. This includes fixes for Visual Studio on Windows.

## 1.0.1 (2012-02-07)

- `PyInt_FromLong` was renamed to `PyLong_FromLong` in Python 3. A macro has been added to fix this. (#7)
- Included the C file generated by Cython again and made Cython an optional dependency. The `.pyx` file can be compiled with the `--cython` option. (#6, #8)

## 1.0.0 (2012-02-04)

- Reimplemented existing functionality in Cython.
- Added renderer classes for customized Markdown rendering (like Redcarpet has).
- Updated Sundown files; See commits from Aug 20, 2011 to Jan 27, 2012.

## 0.4.2 (2011-08-25)

- Updated Sundown files; See commits from 2011-08-03 to 2011-08-09.

## 0.4.1 (2011-08-01)

- Fixed buffer management. It was broken and leaked memory. (tanoku)
- Updated Sundown files; See commits from 2011-07-29 to 2011-08-01.

## 0.4.0 (2011-07-25)

- API change: `misaka.toc` has been removed. Instead `HTML_TOC_TREE` has to be passed with `misaka.html` to get a TOC tree. When `HTML_TOC` is used the text will be rendered as usual, but the header HTML will be adjusted for the TOC.
- Updated Sundown files; See commits from 2011-07-22 to 2011-07-24.
- Added support for the Superscript extension.

## 0.3.3 (2011-07-22)

- Fix a typo in `README.txt`. (heintz)
- Fix non-NULL-terminated `kwlist` in `misaka_html`. (heintz)
- Rename module to misaka in benchmark.py. (honza)
- Renamed Upskirt to Sundown and updated the source files from 2011-07-04.

## 0.3.2 (2011-07-03)

- Fixed minor error in `setup.py`.

## 0.3.1 (2011-07-03)

- Renamed project to Misaka.
- Updated Upskirt files; See commits from 2011-06-06 to 2011-06-23.

## 0.3.0 (2011-06-16)

- Added Python 3 support.
- Updated Upskirt files; See commits from 2011-06-05 to 2011-06-09.

## 0.2.1 (2011-06-05)

- Updated Upskirt files; See commits from 2011-05-18 to 2011-06-02.

## 0.2.0 (2011-05-17)

- Added Smartypants render flag.
- Added a `toc` function that outputs a table of contents.
- Renamed `markdown` function to `html`.
- Updated Upskirt files; See commits from 2011-05-02 to 2011-05-17.

## 0.1.1 (2011-05-01)

- Updated Upskirt files; a HTML escaping bug in the XHTML renderer was fixed.

## 0.1.0 (2011-05-01)

- Initial release.